==> jangaroo-sdk-0.9.3.zip: joo/classes/ext/config/pivotgridview.js <==
joo.classLoader.prepare("package ext.config",/* {*/


/**
 * Specialised GridView for rendering Pivot Grid components. Config can be passed to the PivotGridView via the PivotGrid constructor's viewConfig option: <pre><code>new Ext.grid.PivotGrid({
 viewConfig: {
 title: 'My Pivot Grid',
 getCellCls: function(value) {
 return value &gt; 10 'red' : 'green';
 }
 }
 });
 </code></pre><p>Currently <a href="output/Ext.grid.PivotGridView.html#Ext.grid.PivotGridView-title">title</a> and <a href="output/Ext.grid.PivotGridView.html#Ext.grid.PivotGridView-getCellCls">getCellCls</a> are the only configuration options accepted by PivotGridView. All other interaction is performed via the <a href="Ext.grid.PivotGrid.html">PivotGrid</a> class.</p>
 *
 * <p>This class serves as a
 * typed config object for constructor of class PivotGridView.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.grid.PivotGridView
 */
{ExtConfig:{target:"ext.grid.PivotGridView"}},
"public class pivotgridview extends ext.config.gridview",4,function($$private){;return[ 

  "public function pivotgridview",function pivotgridview$(config/*:Object = null*/) {if(arguments.length<1){config = null;}

    ext.config.gridview.call(this,config);
  },


  /**
   Optional function which should return a CSS class name for each cell value. This is useful when color coding cells based on their value. Defaults to undefined.
   */
  "public native function get getCellCls"/*():Function*/,

  /**
   * @private
   */
  "public native function set getCellCls"/*(value:Function):void*/,

  /**
   Optional title to be placed in the top left corner of the PivotGrid. Defaults to an empty string.
   */
  "public native function get title"/*():String*/,

  /**
   * @private
   */
  "public native function set title"/*(value:String):void*/,


];},[],["ext.config.gridview"], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/ext/config/pivotgridview.js <==
joo.classLoader.prepare("package ext.config",/* {*/


/**
 * Specialised GridView for rendering Pivot Grid components. Config can be passed to the PivotGridView via the PivotGrid constructor's viewConfig option: <pre><code>new Ext.grid.PivotGrid({
 viewConfig: {
 title: 'My Pivot Grid',
 getCellCls: function(value) {
 return value &gt; 10 'red' : 'green';
 }
 }
 });
 </code></pre><p>Currently <a href="output/Ext.grid.PivotGridView.html#Ext.grid.PivotGridView-title">title</a> and <a href="output/Ext.grid.PivotGridView.html#Ext.grid.PivotGridView-getCellCls">getCellCls</a> are the only configuration options accepted by PivotGridView. All other interaction is performed via the <a href="Ext.grid.PivotGrid.html">PivotGrid</a> class.</p>
 *
 * <p>This class serves as a
 * typed config object for constructor of class PivotGridView.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.grid.PivotGridView
 */
{ExtConfig:{target:"ext.grid.PivotGridView"}},
"public class pivotgridview extends ext.config.gridview",4,function($$private){var $1=ext.config;return[ 

  "public function pivotgridview",function pivotgridview(config/*:Object = null*/) {if(arguments.length<=0)config=null;

     $1.gridview.call(this,config);
  },


  /**
   Optional function which should return a CSS class name for each cell value. This is useful when color coding cells based on their value. Defaults to undefined.
   */
  "public native function get getCellCls"/*():Function*/,

  /**
   * @private
   */
  "public native function set getCellCls"/*(value:Function):void*/,

  /**
   Optional title to be placed in the top left corner of the PivotGrid. Defaults to an empty string.
   */
  "public native function get title"/*():String*/,

  /**
   * @private
   */
  "public native function set title"/*(value:String):void*/,


undefined];},[],["ext.config.gridview"], "0.8.0", "0.9.12"
);
